package com.esignlive.example;

import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.builder.SignerBuilder.ChallengeBuilder;

import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignatureBuilder.signatureFor;
import static com.silanis.esl.sdk.builder.SignerBuilder.newSignerWithEmail;
import static com.silanis.esl.sdk.builder.SignerInformationForEquifaxUSABuilder.newSignerInformationForEquifaxUSA;

import java.util.Calendar;
import java.util.Date;

public class signerAuthenticationMethods {
	
	//replace api_key placeholder with your own value
	public static final String API_KEY = "api_key";
	public static final String API_URL = "https://sandbox.e-signlive.com/api";

	public static void main(String[] args) {

		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		/*-----------------------------EMAIL, Q&A, AND SMS AUTHENTICATION-----------------------*/
		
		DocumentPackage documentPackage = newPackageNamed("Signer Authentication Method")
				.withSigner(newSignerWithEmail("first.signer@example.com")
						.withFirstName("First")
						.withLastName("Signer")
						.challengedWithQuestions(ChallengeBuilder.firstQuestion("What's your favorite sport?")
								.answer("soccer")
								.secondQuestion("What music instrument do you play?")
								.answer("drums")))
				.withSigner(newSignerWithEmail("second.signer@example.com")
						.withFirstName("Second")
						.withLastName("Signer")
						.withSmsSentTo("1234567890"))
				.withDocument(newDocumentWithName("My document")
						.fromFile("DOC_FILE_PATH")
						.withSignature(signatureFor("first.signer@example.com")
								.onPage(0)
								.atPosition(100, 200))
						.withSignature(signatureFor("second.signer@example.com")
								.onPage(0)
								.atPosition(100, 300)))
				.build();

		PackageId packageId = eslClient.createPackage(documentPackage);

		eslClient.sendPackage(packageId);
		
		/*--------------------------KNOWLEDGE-BASED AUTHENTICATION (KBA)--------------------------------------*/

		Calendar cal = Calendar.getInstance();
		cal.set(1967, Calendar.AUGUST, 6); // Year, month and day of month
		Date date = cal.getTime();
		System.out.println(date);

		DocumentPackage superDuperPackage = newPackageNamed("Knowledge Based Authentication")
				.describedAs("Sample Test")
				.withSigner(newSignerWithEmail("esl.signer@example.com")
						.withFirstName("John")
						.withLastName("Smith")
						.challengedWithKnowledgeBasedAuthentication(newSignerInformationForEquifaxUSA()
										.withFirstName("firstName")
										.withLastName("lastName")
										.withSocialSecurityNumber("socialNumber")
										.withStreetAddress("address")
										.withCity("city")
										.withZip("zipCode")
										.withState("state")
										.withDateOfBirth(date)
										.withHomePhoneNumber("phoneNumber")))
				.withDocument(newDocumentWithName("My Document")
						.fromFile("DOC_FILE_PATH")
						.withSignature(signatureFor("esl.signer@example.com").build()))
				.build();

		PackageId packageId2 = eslClient.createAndSendPackage(superDuperPackage);

	}
}